\name{SS.oneway.bf}
\alias{SS.oneway.bf}
\title{Bayes factors for one-way analysis of variance models.
}
\description{
Function to calculate the Bayes factor for a one-way analysis of
  variance layout with vague or improper priors.
}
\usage{
SS.oneway.bf(group.sizes, Fstat)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{group.sizes}{Sizes of groups in the one-way layout}
  \item{Fstat}{F statistic obtained}
}
\details{
  The function the Bayes factor corresponding to a given F statistic
  in a one-way analysis of variance model is calculated using the method 
  of Spiegelhalter and Smith 1982. With improper priors the marginal
  probabilities of the data under each of the models (corresponding to
  the NULL and alternative hypotheses) is indeterminate. This is
  resolved by updating each prior with a small imaginary training
  sample, which is equivalent to normalising the Bayes factor to be 1
  for the small training sample. Spiegelhalter and Smith obtain a
  formula for the Bayes factor in terms of the classical F value.
  
}
\value{
  Returns the Bayes factor corresponding to the given design and
  observed value of F statistic.
}
\references{
Spiegelhalter, D. and A.F.M. Smith 1982
  Bayes factors for linear and log-linear models with vague prior
  information J. Royal Statist Soc. B 44: 377--387.
}
\author{Rod Ball \email{rod.ball@forestresearch.co.nz} 
\url{www.forestresearch.co.nz}}
%\note{ ~~further notes~~ }
% ~Make other sections like Warning with \section{Warning }{....} ~ 
\seealso{\code{\link{oneway.bf.alpha}},\code{\link{oneway.bf.alpha.required}}}
\examples{
# Bayes factors corresponding to P-values 0.05,0.01,0.001,0.0001 for n=200
SS.oneway.bf(group.sizes=c(50,100,50),Fstat=qf(0.95,2,197))
SS.oneway.bf(group.sizes=c(50,100,50),Fstat=qf(0.99,2,197))
SS.oneway.bf(group.sizes=c(50,100,50),Fstat=qf(0.999,2,197))
SS.oneway.bf(group.sizes=c(50,100,50),Fstat=qf(0.9999,2,197))
}

\keyword{htest}% at least one, from doc/KEYWORDS
\keyword{models }% __ONLY ONE__ keyword per line

\eof
\name{ld.design}
\alias{ld.design}
\alias{ld.power}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Functions for design of experiments to detect linkage disequilibrium}
\description{
  Find the sample size required to detect linkage disequilibrium with
  a given Bayes factor, with a given power, or find the power of
  experimental designs to detect linkage equilibrium with a given
  Bayes factor.
}
\usage{
ld.design(p, q, D, h2, phi, Bf, power, nmin = 50, nmax = 1e+05, ninterp = 50, 
          missclass.rate = 0, print.it = FALSE)
ld.power(n, p, q, D, h2, phi, Bf, missclass.rate = 0)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{n}{\code{ld.power:} vector of sample sizes}
  \item{p}{Bi-allelic marker allele frequency}
  \item{q}{Bi-allelic QTL allele frequency}
  \item{D}{Linkage disequilibrium coefficient}
  \item{h2}{QTL `heritability', i.e. proportion of total or phenotypic
    variance explained by the QTL}
  \item{phi}{Dominance ratio: \code{phi} = 0 denotes purely additive, 
    \code{phi} = 1 denotes purely dominant allele effects}
  \item{Bf}{Bayes factor}
  \item{power}{\code{ld.design:} Power, or probability of detecting an effect with Bayes
    factor greater than Bf}
  \item{nmin}{\code{ld.design:} Lower bound for sample size}
  \item{nmax}{\code{ld.design:} Upper bound for sample size}
  \item{ninterp}{\code{ld.design:} Number of sample sizes to try}
  \item{missclass.rate}{Proportion of marker values which are
    missclassified, i.e. incorrect (to allow for genotyping errors)}
  \item{print.it}{If TRUE print results for sample sizes tried}
}
\details{
These functions implement the method described in Ball (2003) for
obtaining the power of designs for detecting linkage disequilibrium with
a given Bayes factor. The F values, (and hence significance levels) 
corresponding to the given Bayes factors, sample sizes, and marker genotype 
frequecies, are calculated using the method of Spiegelhalter and Smith (1982) 
(R functions \code{\link{oneway.bf.alpha.required}},
\code{\link{SS.oneway.bf}}). The power is obtained using a corrected
version of the classical deterministic power calculation from 
Luo (1988) (R function \code{\link{luo.ld.power}}).
}

\value{
  For \code{ld.power}, a matrix with columns: 
  \item{n}{Sample sizes}
  \item{power}{Power of the design with the given sample sizes}
  Additionally the return value has attributes indicating the
  linkage disequilibrium parameters used.
  For \code{ld.design} the sample size is returned.
}
\references{
  Ball, R.D. 2003
  Experimental designs for reliable detection of linkage disequilibrium
  in unstructured random population association studies.

  Luo, Z.W. 1988
  Detecting linkage disequilibrium between a polymorphic marker locus and 
  a trait locus in natural populations. Heredity 80, 198--208

  Spiegelhalter, D. and A.F.M. Smith 1982
  Bayes factors for linear and log-linear models with vague prior
  information J. Royal Statist Soc. B 44: 377--387.
}
\author{Rod Ball \email{rod.ball@forestresearch.co.nz} 
\url{www.forestresearch.co.nz}}
%\note{ ~~further notes~~ }
% ~Make other sections like Warning with \section{Warning }{....} ~ 
\seealso{ \code{\link{luo.ld.power}}, \code{\link{ld.sim}}, \code{\link{oneway.bf.alpha}},
\code{\link{oneway.bf.alpha.required}}, \code{\link{SS.oneway.bf}}}
\examples{
ld.power(n=seq(100,1000,by=100),p=0.5,q=0.5,D=0.1,h2=0.1,phi=0,Bf=20)
ld.design(p=0.5,q=0.5,D=0.1,h2=0.1,phi=0,Bf=20,power=0.9,print.it=TRUE,nmin=600,nmax=4000)
ld.design(p=0.5,q=0.5,D=0.1,h2=0.1,phi=0,Bf=20,power=0.9,print.it=FALSE,nmin=1700,nmax=1900)
}
\keyword{design }% at least one, from doc/KEYWORDS


\eof
\name{ld.sim}
\alias{ld.sim}
\alias{ld.sim1}
\title{Functions to simulate populations with a bi-allelic marker and QTL in linkage 
disequilibrium and test for association.}
\description{
For a bi-allelic marker and QTL, with given allele frequencies, linkage disequilibrium, and QTL 
heritability, multiple replicate populations with marker, QTL, and trait values are simulated 
and tested for a marker-trait association. Results can be used to estimate the power of an experimental 
design for detecting linkage disequilibrium.
}
\usage{
ld.sim(nsim, n, p, q, D, h2, Vp, phi, missclass.rate = 0, sim.chunk = 100, 
       method = 1, print.it = TRUE)
ld.sim1(n, p, q, D, d, h, sig2.error, missclass.rate = 0, nreps = 1, 
        method = 2, print.it = TRUE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{nsim}{Number of replicate simulations to do}
  \item{n}{The sample size, i.e. number of individuals
    genotyped and tested for the trait of interest }
  \item{p}{Bi-allelic marker allele frequency}
  \item{q}{Bi-allelic QTL allele frequency}
  \item{D}{Linkage disequilibrium coefficient}
  \item{h2}{QTL `heritability', i.e. proportion of total or phenotypic
    variance explained by the QTL}
  \item{Vp}{\code{ld.sim:} Total or phenotypic variance: an arbitrary value may be used}
  \item{phi}{\code{ld.sim:} Dominance ratio: \code{phi = 0} denotes purely additive
    gene action, \code{phi = 1} denotes completely dominant gene action}
  \item{d}{\code{ld.sim1:} Expected value for trait when QTL genotype is QQ,qq respectively is d,-d}
  \item{h}{\code{ld.sim1:} Expected value for trait when QTL genotype is Qq is h}
  \item{sig2.error}{\code{ld.sim1:} Error variance when QTL genotype known and modelled}
  \item{missclass.rate}{Proportion of marker values which are
    missclassified, i.e. incorrect}
  \item{sim.chunk}{\code{ld.sim:} Number of replicates to do in a
    `chunk' in each call to \code{ld.sim1}}
  \item{nreps}{\code{ld.sim1:} Number of replicate simulations to do for
    the given set of marker genotypes}
  \item{method}{If \code{method=1} simulate random QTL genotypes
    conditional on marker values in \code{ld.sim1}; if \code{method=2} 
    simulate markers and QTL directly from table of joint probabilities. 
    With \code{method=1}, a common set of marker values are used for each of 
    the \code{nreps} replicates per call to \code{ld.sim1}, enabling MANOVA to be used.}
  \item{print.it}{if \code{TRUE}, print results}
}
\details{
  Marker, QTL, and trait values are simulated according to the genetic
  model with normal errors. In \code{ld.sim}, QTL parameters \code{d,h} are determined from the
  parameters \code{h2,q,phi}, and \code{Vq}, and the main simulation done for each
  chunk of replicates by a call to \code{ld.sim1}. Marker-trait  association is tested by 
  a one-way analysis of variance of trait values in terms of marker classes.
  The proportion of  results with P-value over a given threshold gives a stochastic estimate
  of the power calculated by \code{\link{luo.ld.power}}.
}
\value{
  An array with 1 row per simulation run, and 4 columns with values for
  each run:
  \item{MS.beta}{Between marker classes mean square}
  \item{MS.within}{Within marker classes mean square}
  \item{F.value}{F value}
  \item{P.value}{P value}
}
\references{Luo, Z.W. 1988 Detecting linkage disequilibrium between a
 polymorphic marker locus and a trait locus in natural populations.
 Heredity 80, 198--208.}
\author{Rod Ball \email{rod.ball@forestresearch.co.nz} 
\url{www.forestresearch.co.nz}}
%\note{ ~~further notes~~ }
% ~Make other sections like Warning with \section{Warning }{....} ~ 
\seealso{\code{\link{luo.ld.power}}}
\examples{
# Power from stochastic simulation for Luo's population 12
data(luo.ld.populations)
luo.pop12.sim <- ld.sim(nsim=3000,
                        n=luo.ld.populations[12,"n"],
                        p=luo.ld.populations[12,"p"],
                        q=luo.ld.populations[12,"q"],
                        D=luo.ld.populations[12,"D"],
                        h2=luo.ld.populations[12,"h2"],
                        phi=luo.ld.populations[12,"phi"],
                        Vp=100)
# power
table(luo.pop12.sim[,4] < 0.05)[2]/sum(table(luo.pop12.sim[,4] < 0.05))
# Cf power from deterministic calculation
luo.ld.power(n=luo.ld.populations[12,"n"],
             p=luo.ld.populations[12,"p"],
             q=luo.ld.populations[12,"q"],
             D=luo.ld.populations[12,"D"],
             h2=luo.ld.populations[12,"h2"],
             phi=luo.ld.populations[12,"phi"],
             Vp=100,
             alpha=0.05)
}
\keyword{design}% at least one, from doc/KEYWORDS

\eof
\name{luo.ld.populations}
\alias{luo.ld.populations}
\docType{data}
\title{Luo's Linkage disequilibrium example populations}
\description{
Matrix with rows containing parameters (population size, allele
frequencies, disequilibrium, dominance ratio) for example populations
with a bi-allelic marker and QTL in linkage disequilibrium, from Luo (1998).
}
\usage{data(luo.ld.populations)}
\format{
  The format is:
 num [1:12, 1:7] 1 2 3 4 5 6 7 8 9 10 ...
 - attr(*, "dimnames")=List of 2
  ..$ : NULL
  ..$ : chr [1:7] "pop." "n" "p" "q" ...
}
%\details{
%  ~~ If necessary, more details than the __description__ above ~~
%}
\source{
Luo, Z.W. 1988 Detecting linkage disequilibrium between a
 polymorphic marker locus and a trait locus in natural populations.
 Heredity 80, 198--208.
}
%\references{
%  ~~ possibly secondary sources and usages ~~
%}
\examples{
data(luo.ld.populations)
luo.ld.populations
%## maybe str(luo.ld.populations) ; plot(luo.ld.populations) ...
}
\keyword{datasets}

\eof
\name{luo.ld.power}
\alias{luo.ld.power}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Classical deterministic power calculation for association studies to detect
  linkage disequilibrium}
\description{Classical deterministic power calculation for power to detect linkage
disequilibrium between a bi-allelic QTL and a bi-allelic marker, at a
given significance level in a population level association study.  
}
\usage{
luo.ld.power(n, p, q, D, h2, phi, Vp = 100, alpha, print.it = T, 
             missclass.rate = 0)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{n}{The sample size, i.e. number of individuals
    genotyped and tested for the trait of interest }
  \item{p}{Bi-allelic marker allele frequency}
  \item{q}{Bi-allelic QTL allele frequency}
  \item{D}{Linkage disequilibrium coefficient}
  \item{h2}{QTL `heritability', i.e. proportion of total or phenotypic
    variance explained by the QTL}
  \item{phi}{Dominance ratio: \code{phi} = 0 denotes purely additive, 
\code{phi} = 1 denotes purely dominant allele effects}
  \item{Vp}{Total or phenotypic variance: and arbitrary value may be used}
  \item{alpha}{Significance level for hypothesis tests}
  \item{print.it}{If TRUE print summary of results}
  \item{missclass.rate}{Proportion of marker values which are
    missclassified, i.e. incorrect}
}
\details{
This is based on the 'fixed model' power calculation from Luo (1998,
Heredity 80, 198--208), with corrections described in Ball (2003).  This
function, combined with \code{\link{oneway.bf.alpha}}, 
\code{\link{oneway.bf.alpha.required}}, is used in
Ball (2003) to design experiments for detecting linkage disequilibrium
with a given power to achieve a given Bayes factor.
}
\value{
  Returns the power, or probability of detecting an effect, with the
  given parameters, at the given significance level.
}

\references{
  Ball, R.D. 2003
  Experimental designs for reliable detection of linkage disequilibrium
  in unstructured random population association studies.

  Luo, Z.W. 1988
  Detecting linkage disequilibrium between a polymorphic marker locus and 
  a trait locus in natural populations. Heredity 80, 198--208}

\author{Rod Ball \email{rod.ball@forestresearch.co.nz} 
\url{www.forestresearch.co.nz}}
%\note{ ~~further notes~~ }
% ~Make other sections like Warning with \section{Warning }{....} ~ 
\seealso{\code{\link{ld.sim}},\code{\link{oneway.bf.alpha}},\code{\link{oneway.bf.alpha.required}},
\code{\link{SS.oneway.bf}}}
\examples{
data(luo.ld.populations)
options(digits=3)
powers <- numeric(nrow(luo.ld.populations))
for(ii in 1:nrow(luo.ld.populations)){
   cat("ii=",ii,"\n")
   powers[ii] <- luo.ld.power(n=luo.ld.populations[ii,"n"],
                              p=luo.ld.populations[ii,"p"],
                              q=luo.ld.populations[ii,"q"],
                              D=luo.ld.populations[ii,"D"],
                              h2=luo.ld.populations[ii,"h2"],
                              phi=luo.ld.populations[ii,"phi"],
                              Vp=100,
                              alpha=0.05)
}
cbind(luo.ld.populations,power=powers)
}
\keyword{design}% at least one, from doc/KEYWORDS


\eof
\name{oneway.bf.alpha}
\alias{oneway.bf.alpha}
\alias{oneway.bf.alpha.required}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Correspondence between significance levels and Bayes factors for
  effects of marker genotype classes.}
\description{
Functions to calculate the correspondence between significance levels alpha 
  and the Bayes factor, for association between a bi-allelic marker and
  QTL, for given sample sizes and marker genotype frequencies for
  bi-allelic marker.
}
\usage{
  oneway.bf.alpha(n, group.sizes = c(0.25, 0.5, 0.25) * n, alpha = 0.05)
  oneway.bf.alpha.required(n, group.sizes = c(0.25, 0.5, 0.25) * n, Bf)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{n}{Sample size, i.e. number of individuals genotyped
    and phenotyped for the trait}
  \item{group.sizes}{Number in each of the 3 possible marker genotype
    classes MM, Mm, mm}
  \item{alpha}{Significance level, i.e. threshold for `detection'}
  \item{Bf}{Bayes factor, used as threshold for detection} }

\details{These functions implement the correspondence between the 
  significance levels and Bayes factors used in Ball (2003) to design
  experiments for detecting linkage disequilibrium with a given power 
  to achieve a given Bayes factor. The function \code{\link{SS.oneway.bf}} is used to calculate
  the Bayes factor corresponding to a given F statistic (Spiegelhalter
  and Smith 1982). This is combined with a call to \code{qf}, for \code{oneway.bf.alpha}
  or calls to \code{pf} and interpolation for
  \code{oneway.bf.alpha.required}, to calculate the Bayes factor
  corresponding to a given alpha or alpha values for a given Bayes factor.
 }
}
\value{
\code{oneway.bf.alpha} returns the Bayes factor
corresponding to a given significance level (alpha).
\code{oneway.bf.alpha.required} returns the significance level (alpha)
corresponding to a given Bayes factor.
}
\references{ 
  Ball, R.D. 2003
  Experimental designs for reliable detection of linkage disequilibrium
  in unstructured random population association studies.

  Spiegelhalter, D. and A.F.M. Smith 1982
  Bayes factors for linear and log-linear models with vague prior
  information J. Royal Statist Soc. B 44: 377--387.
}
\author{Rod Ball \email{rod.ball@forestresearch.co.nz} 
\url{www.forestresearch.co.nz}}
%\note{ ~~further notes~~ }
% ~Make other sections like Warning with \section{Warning }{....} ~ 
\seealso{\code{\link{SS.oneway.bf}},\code{\link{luo.ld.power}} }
\examples{
# calculations for Table 4 in the manuscript
data(luo.ld.populations)
Bs <- numeric(nrow(luo.ld.populations))
n.Bf20s <- numeric(nrow(luo.ld.populations))
ns <- c(seq(200,400,by=25),,450,seq(500,4000,by=100))
powers <- numeric(length(ns))
alphas <- numeric(length(ns))
P.Bf20s <- numeric(length(ns))
for(ii in 1:nrow(luo.ld.populations)){
   cat("ii=",ii,"\n")
   powers[ii] <- luo.ld.power(n=luo.ld.populations[ii,"n"],
                              p=luo.ld.populations[ii,"p"],
                              q=luo.ld.populations[ii,"q"],
                              D=luo.ld.populations[ii,"D"],
                              h2=luo.ld.populations[ii,"h2"],
                              phi=luo.ld.populations[ii,"phi"],
                              Vp=100,
                              alpha=0.05)

   p1 <- luo.ld.populations[ii,"p"]
   Bs[ii] <- oneway.bf.alpha(n=luo.ld.populations[ii,"n"],
                 group.sizes=c(p1^2,2*p1*(1-p1),(1-p1)^2)*
                                 luo.ld.populations[ii,"n"])
   for(jj in seq(along=ns)){
     alphas[jj] <- oneway.bf.alpha.required(ns[jj],
                       group.sizes=c(p1^2,2*p1*(1-p1),(1-p1)^2)*ns[jj],Bf=20)
     P.Bf20s[jj] <- luo.ld.power(n=ns[jj],
                                 p=luo.ld.populations[ii,"p"],
                                 luo.ld.populations[ii,"q"],
                                 D=luo.ld.populations[ii,"D"],
                                 h2=luo.ld.populations[ii,"h2"],
                                 phi=luo.ld.populations[ii,"phi"],
                                 Vp=100,
                                 alpha=alphas[jj],
                                 print.it=FALSE)
   }
   n.Bf20s[ii] <- approx(P.Bf20s,ns,xout=0.9)$y
   cat("n =",n.Bf20s[ii],"\n")
}
cbind(luo.ld.populations,powers,n.Bf20s)

}



\keyword{htest}
\keyword{models}

\eof
